# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class AnnotationFilterOptions(UniversalBaseModel):
    usual: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Include not skipped and not ground truth annotations
    """

    ground_truth: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Include ground truth annotations
    """

    skipped: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Include skipped annotations
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ....core.pydantic_utilities import UniversalBaseModel
import typing
import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2


class AzureUpdateResponse(UniversalBaseModel):
    can_delete_objects: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Deletion from storage enabled
    """

    title: typing.Optional[str] = pydantic.Field(default=None)
    """
    Storage title
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Storage description
    """

    project: typing.Optional[int] = pydantic.Field(default=None)
    """
    Project ID
    """

    container: typing.Optional[str] = pydantic.Field(default=None)
    """
    Azure blob container
    """

    prefix: typing.Optional[str] = pydantic.Field(default=None)
    """
    Azure blob prefix name
    """

    account_name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Azure Blob account name
    """

    account_key: typing.Optional[str] = pydantic.Field(default=None)
    """
    Azure Blob account key
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class ProjectsUpdateResponse(UniversalBaseModel):
    """
    Project
    """

    title: typing.Optional[str] = pydantic.Field(default=None)
    """
    Project title
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Project description
    """

    label_config: typing.Optional[str] = pydantic.Field(default=None)
    """
    Label config in XML format
    """

    expert_instruction: typing.Optional[str] = pydantic.Field(default=None)
    """
    Labeling instructions to show to the user
    """

    show_instruction: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Show labeling instructions
    """

    show_skip_button: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Show skip button
    """

    enable_empty_annotation: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Allow empty annotations
    """

    show_annotation_history: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Show annotation history
    """

    reveal_preannotations_interactively: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Reveal preannotations interactively. If set to True, predictions will be shown to the user only after selecting the area of interest
    """

    show_collab_predictions: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Show predictions to annotators
    """

    maximum_annotations: typing.Optional[int] = pydantic.Field(default=None)
    """
    Maximum annotations per task
    """

    annotation_limit_count: typing.Optional[int] = pydantic.Field(default=None)
    """
    Maximum number of annotations per annotator
    """

    annotation_limit_percent: typing.Optional[float] = pydantic.Field(default=None)
    """
    Maximum percentage of annotations per annotator
    """

    color: typing.Optional[str] = pydantic.Field(default=None)
    """
    Project color in HEX format
    """

    control_weights: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    Dict of weights for each control tag in metric calculation. Each control tag (e.g. label or choice) will have its own key in control weight dict with weight for each label and overall weight. For example, if a bounding box annotation with a control tag named my_bbox should be included with 0.33 weight in agreement calculation, and the first label Car should be twice as important as Airplane, then you need to specify: {'my_bbox': {'type': 'RectangleLabels', 'labels': {'Car': 1.0, 'Airplane': 0.5}, 'overall': 0.33}
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing_extensions
from ...core.serialization import FieldMetadata
import pydantic
import typing
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class ActionsCreateRequestSelectedItemsIncluded(UniversalBaseModel):
    all_: typing_extensions.Annotated[bool, FieldMetadata(alias="all")] = pydantic.Field()
    """
    No tasks are selected
    """

    included: typing.Optional[typing.List[int]] = pydantic.Field(default=None)
    """
    List of included task IDs
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
